@@ -1,5 +1,6 @@
 from clickable.config.project import ProjectConfig
 from clickable.commands.docker.docker_config import DockerConfig
+from clickable.utils import get_existing_dir
 from .docker_support import DockerSupport
 import os
 import getpass
@@ -15,11 +16,21 @@ class MultimediaSupport(DockerSupport):
         uid = os.getuid()
         user = getpass.getuser()
 
+        pulse_run_dir = get_existing_dir('Pulse run', [
+            f'/run/user/{uid}/pulse',
+            f'/run/{uid}/pulse',
+        ])
+
+        pulse_conf_dir = get_existing_dir('Pulse configuration', [
+            f'/home/{user}/.pulse',
+            f'/home/{user}/.config/pulse',
+        ])
+
         docker_config.volumes.update({
             '/dev/shm': '/dev/shm',
             '/etc/machine-id': '/etc/machine-id',
-            '/run/user/{}/pulse'.format(uid): '/run/user/1000/pulse',
+            pulse_run_dir: '/run/user/1000/pulse',
             '/var/lib/dbus': '/var/lib/dbus',
-            '/home/{}/.pulse'.format(user): '/home/phablet/.pulse',
+            pulse_conf_dir: '/home/phablet/.pulse',
             '/dev/snd': '/dev/snd',
         })
