@@ -80,11 +80,13 @@ class ProjectConfig():
     # Dicts where keys accept placeholders
     accepts_placeholders_keys = ["install_data", "env_vars"]
 
-    # Paths to be made absolute, iterates and recurses lists and dicts
-    path_keys = ['root_dir', 'build_dir', 'src_dir', 'install_dir',
-                 'cargo_home', 'gopath', 'app_lib_dir', 'app_bin_dir',
-                 'app_qml_dir', 'build_home',
-                 'install_qml', 'install_bin', 'install_lib', 'install_root_data']
+    # Paths to be checked for sanity, iterates and recurses lists and dicts
+    path_keys = ['install_qml', 'install_bin', 'install_lib']
+    # Like `path_keys`, but made absolute
+    absolute_path_keys = ['root_dir', 'build_dir', 'src_dir', 'install_dir',
+                          'cargo_home', 'gopath', 'app_lib_dir', 'app_bin_dir',
+                          'app_qml_dir', 'build_home',
+                          'install_root_data']
     # Same as for path_keys, except that for dicts the keys are made
     # absolute, not the values
     path_dict_keys = ['install_data']
@@ -188,6 +190,9 @@ class ProjectConfig():
             'rust_channel': None,
             'framework': None,
             'always_clean': False,
+            'skip_review': False,
+            'ignore_review_warnings': None,
+            'ignore_review_errors': None,
         }
 
     def parse_configs(self, args, commands, always_clean):
@@ -226,7 +231,6 @@ class ProjectConfig():
         self.handle_path_keys_and_placeholders()
 
         self.setup_helpers()
-        self.set_env_vars()
 
         for key, value in self.config.items():
             logger.debug('App config value %s: %s', key, value)
@@ -354,6 +358,19 @@ class ProjectConfig():
         self.set_build_arch()
         self.config['arch_rust'] = Constants.rust_arch_target_mapping[self.build_arch]
 
+    def get_image_framework(self):
+        if self.config['framework'] in Constants.framework_image_mapping:
+            return Constants.framework_image_mapping[self.config['framework']]
+
+        return Constants.framework_image_fallback[self.get_framework_base()]
+
+    def get_framework_base(self):
+        for base in Constants.framework_base:
+            if self.config['framework'].find(base) != -1:
+                return base
+
+        return Constants.framework_base_default
+
     def setup_image(self):
         if self.needs_clickable_image():
             self.check_nvidia_mode()
@@ -366,15 +383,13 @@ class ProjectConfig():
             if self.is_ide_command():
                 container_spec += "-ide"
 
-            image_framework = Constants.framework_image_mapping.get(
-                self.config['framework'], Constants.framework_fallback)
-
+            image_framework = self.get_image_framework()
             container_mapping_host = Constants.container_mapping[Constants.host_arch]
             container = container_mapping_host.get((image_framework, container_spec), None)
 
             if not container:
                 raise ClickableException(
-                    f'There is currently no docker image for {image_framework}/{container_spec}'
+                    f'There is currently no docker image for {image_framework}-{container_spec}'
                 )
 
             self.config['docker_image'] = container
@@ -399,7 +414,7 @@ class ProjectConfig():
             super().__setattr__(name, value)
 
     def load_project_config(self, config_path):
-        config = {}
+        config_dict = {}
         use_default_config = not config_path
         if use_default_config:
             directory = self.cwd
@@ -447,18 +462,12 @@ class ProjectConfig():
                 absolute_path = make_absolute(config_path)
                 relative_path = PurePath(absolute_path).relative_to(self.config['root_dir'])
                 validate_config_format(config_dict, schema, 'project', relative_path)
-
-                for key in self.config:
-                    value = config_dict.get(key, None)
-
-                    if value:
-                        config[key] = value
         elif not use_default_config:
             raise ClickableException(
                 f'Specified config file "{config_path}" does not exist.'
             )
 
-        return config
+        return config_dict
 
     def merge_cli_config(self):
         if self.global_config.cli.default_chain:
@@ -606,7 +615,7 @@ class ProjectConfig():
 
         # Make paths absolute that don't accept placeholders.
         # They may be used as placeholders themselves.
-        for key in set(self.path_keys) - set(accepting):
+        for key in set(self.absolute_path_keys) - set(accepting):
             self.config[key] = make_absolute(self.config[key], change_keys=False)
         for key in set(self.path_dict_keys) - set(accepting):
             self.config[key] = make_absolute(self.config[key], change_keys=True)
@@ -618,7 +627,7 @@ class ProjectConfig():
             if key in self.accepts_placeholders_keys:
                 self.handle_accepting_key(key, change_keys=True)
 
-            if key in self.path_keys:
+            if key in self.absolute_path_keys:
                 self.config[key] = make_absolute(self.config[key], change_keys=False)
             if key in self.path_dict_keys:
                 self.config[key] = make_absolute(self.config[key], change_keys=True)
@@ -870,7 +879,7 @@ class ProjectConfig():
                 raise ClickableException('Desktop Mode in Container Mode is not supported.')
 
     def check_path_sanity(self):
-        for path in self.path_keys:
+        for path in self.path_keys + self.absolute_path_keys:
             if self.config[path] and not is_path_sane(self.config[path]):
                 raise ClickableException(
                     f'The "{path}" config contains special characters (e.g. spaces):\n'
